@@ -1063,15 +1063,15 @@ void drumkv1widget::newPreset (void)
 	qDebug("drumkv1widget::newPreset()");
 #endif
 
-	clearElements();
-	clearSampleFile();
+//	clearElements();
+//	clearSampleFile();
 
 	resetParamKnobs(drumkv1::NUM_PARAMS);
 	resetParamValues(drumkv1::NUM_PARAMS);
 
 	drumkv1_ui *pDrumkUi = ui_instance();
 	if (pDrumkUi)
-		pDrumkUi->reset();
+		pDrumkUi->newPreset();
 
 	refreshElements();
 	activateElement();
@@ -1088,8 +1088,8 @@ bool drumkv1widget::loadPreset ( const QString& sFilename )
 	qDebug("drumkv1widget::loadPreset(\"%s\")", sFilename.toUtf8().constData());
 #endif
 
-	clearElements();
-	clearSampleFile();
+//	clearElements();
+//	clearSampleFile();
 
 	resetParamKnobs(drumkv1::NUM_PARAMS);
 	resetParamValues(drumkv1::NUM_PARAMS);
